"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Gene = void 0;
class Gene {
    constructor({ trait, alleles, genetics }) {
        if (alleles.some((allele) => allele.trait !== trait)) {
            throw new Error("allele trait must match the gene trait");
        }
        this._trait = trait;
        this._alleles = alleles;
        this._genetics = genetics;
    }
    get genetics() {
        return this._genetics;
    }
    get random() {
        return this._genetics.random;
    }
    get type() {
        const [alleleOne, alleleTwo] = this._alleles;
        return alleleOne === alleleTwo ? "homozygous" : "heterozygous";
    }
    get trait() {
        return this._trait;
    }
    get alleles() {
        return [...this._alleles];
    }
    get phenotype() {
        const [alleleOne, alleleTwo] = this._alleles;
        return alleleOne.dominance > alleleTwo.dominance ? alleleOne : alleleTwo;
    }
}
exports.Gene = Gene;
